@@ -180,10 +180,6 @@ class Tasks:
 
         for payload in self.payloads:
 
-            # Clean comment
-            if payload.get('comment'):
-                payload.get['comment'] = str(payload.get('comment'))[:255]
-
             # Convert dict to JSON string
             payload_string = json.dumps(payload)
 
